import React, { useState, useEffect, useRef } from 'react';
import { history, Link } from 'umi';
import { Button, Popconfirm, Modal, Form, Input, message, Radio, Select, Tooltip } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { getRegionList, addRegion, deleteRegion, updateRegion } from '@/services/region';
import { getCooperativeList } from '@/services/cooperative';
import {
  getUserList,
  addUser,
  deleteUser,
  updateUser,
  getDefaultPassword,
  getUserDetail,
} from '@/services/user';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable';
import Search from '@/components/CooperativeSearch';

const FormItem = Form.Item;
const { Option } = Select;

export default (props) => {
  const actions = () => [
    <Button key="add" type="primary" icon={<PlusOutlined />} onClick={() => setEditModal(true)}>
      新增
    </Button>,
  ];
  const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
  const [form] = Form.useForm();
  const [editModal, setEditModal] = useState(false);
  const [loading, setLoading] = useState(false);
  const [userId, setuserId] = useState();
  const [password, setPassWord] = useState('');
  const actionRef = useRef();
  const [cooperativeList, setCooperativeList] = useState([]);

  const Submit = (values) => {
    const newData = { ...values };
    if (!newData.sex && newData.sex !== 0) {
      newData.sex = 1;
    }
    console.log(newData);
    setLoading(true);
    if (!/^1[0-9]{10}$/.test(newData.phone)) {
      message.warning('请输入正确的十一位手机号');
      setLoading(false);
      return false;
    }
    if (userId) {
      updateUser(userId, newData).then(() => {
        setLoading(false);
        message.success(`修改成功`);
        onCancel();
        actionRef.current.reload();
      });
    } else {
      addUser(newData)
        .then(() => {
          setLoading(false);
          message.success(`保存成功`);
          onCancel();
          actionRef.current.reload();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    }
  };
  const handelEdit = (val) => {
    setuserId(val.userId);
    form.setFieldsValue(val);
    setEditModal(true);
  };
  const onCancel = () => {
    setuserId();
    form.resetFields();
    setEditModal(false);
  };
  const handelChange = () => {};
  const handleDelete = (id) => {
    deleteRegion(id)
      .then(() => {
        message.success('删除成功');
        actionRef.current.reload();
      })
      .catch((err) => {
        message.error(err);
      });
  };
  useEffect(() => {
    getDefaultPassword().then((res) => {
      setPassWord(res);
    });
    getCooperativeList().then((res) => {
      setCooperativeList(res.records);
    });
    if (userId) {
    } else {
      form.resetFields();
    }
  }, [userId]);
  const columns = [
    {
      title: '登录账号',
      dataIndex: 'loginName',
      key: 'loginName',
    },
    {
      title: '用户名',
      dataIndex: 'userName',
      key: 'userName',
    },

    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '邮箱',
      dataIndex: 'email',
      key: 'email',
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      render: (_, record) => {
        return record.status === 1 ? '启用' : '未启用';
      },
    },
    {
      title: '操作',
      valueType: 'option',
      render: (_, record) => [
        <a key={1} onClick={() => handelEdit(record)}>
          编辑
        </a>,
        <Popconfirm
          key={2}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.userId)}
          okText="确定"
          cancelText="取消"
        >
          <a href="#">删除</a>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getUserList}
        // expfunc={exportPersonList}
        columns={columns}
        actionRef={actionRef}
        rowKey="userId"
        options={false}
        toolBarRender={actions}
        scroll={{ x: 1000 }}
      />
      <Modal
        title={userId ? '人员编辑' : '人员新增'}
        visible={editModal}
        onCancel={onCancel}
        keyboard={false}
        maskClosable={false}
        destroyOnClose={true}
        footer={null}
      >
        <Form {...formItemLayout} onFinish={Submit} form={form}>
          <FormItem label="登录账号">
            <Input.Group compact>
              <Form.Item
                name="loginName"
                noStyle
                rules={[{ required: true, message: '请输入登录账号' }]}
              >
                <Input placeholder="请输入" />
              </Form.Item>
              <span style={{ opacity: '0.7' }}>默认密码{password}</span>
            </Input.Group>
          </FormItem>
          <FormItem label="用户名" name="userName" rules={[{ required: true, message: '请输入' }]}>
            <Input placeholder="请输入" />
          </FormItem>
          <FormItem label="性别" name="sex">
            <Radio.Group name="sex" defaultValue={1}>
              <Radio value={1}>男</Radio>
              <Radio value={0}>女</Radio>
            </Radio.Group>
          </FormItem>
          <FormItem label="手机号" name="phone" rules={[{ required: true, message: '请输入' }]}>
            <Input maxLength="11" placeholder="请输入" />
          </FormItem>
          <FormItem label="邮箱" name="email" rules={[{ required: true, message: '请输入' }]}>
            <Input placeholder="请输入" />
          </FormItem>
          <FormItem label="所属机构" name="orgId">
            <Search placeholder="请选择机构" onChange={handelChange} />
            {/* <Select
              placeholder="请选择机构"
              showSearch
              onSearch={handelFormSearch}
              onChange={handelFormSearch}
            >
              {cooperativeList.map((item) => (
                <Option value={item.orgId} key={item.orgId}>
                  {item.name}
                </Option>
              ))}
            </Select> */}
          </FormItem>
          <FormItem label=" " colon={false}>
            <Button type="default" onClick={onCancel}>
              取消
            </Button>
            <Button
              type="primary"
              loading={loading}
              htmlType="Submit"
              style={{ marginLeft: '4em' }}
            >
              确认
            </Button>
          </FormItem>
        </Form>
      </Modal>
    </PageHeaderWrapper>
  );
};
